'use strict';

var _assert = require('assert');

var _assert2 = _interopRequireDefault(_assert);

var _helpers = require('../helpers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('matchesTags', function () {
  it('should return true if the tagslist contains no whitelisted tags', function () {
    _assert2.default.equal((0, _helpers.matchesTags)(['~@invalid'], { tags: [{ name: '@valid' }] }), true);
  });

  it('should return true if the feature contains a whitelisted tag', function () {
    _assert2.default.equal((0, _helpers.matchesTags)(['@tag1', '@valid'], { tags: [{ name: '@valid' }] }), true);
  });

  it('should return false if the feature does not contain a whitelisted tag', function () {
    _assert2.default.equal((0, _helpers.matchesTags)(['@valid'], { tags: [{ name: '@invalid' }] }), false);
  });

  it('should return false if the feature contains a blacklisted tag', function () {
    _assert2.default.equal((0, _helpers.matchesTags)(['@valid', '~@invalid'], { tags: [{ name: '@invalid' }, { name: '@valid' }] }), false);
  });
});

describe('featureMatchesTags', function () {
  it('should return true if the feature contains a valid tag', function () {
    var feature = [0, { feature: { tags: [{ name: '@valid' }] } }];
    _assert2.default.equal((0, _helpers.featureMatchesTags)(['@tag1', '@valid'], feature), true);
  });

  it('should return true if any of the features scenarios contains a valid tag', function () {
    var feature = [0, {
      feature: {
        tags: [{ name: '@invalid' }],
        children: [{
          tags: [{ name: '@invalid' }]
        }, {
          tags: [{ name: '@valid' }]
        }]
      }
    }];
    _assert2.default.equal((0, _helpers.featureMatchesTags)(['@valid'], feature), true);
  });

  it('should return false if no valid tags could be found', function () {
    var feature = [0, {
      feature: {
        tags: [{ name: '@invalid' }],
        children: [{
          tags: [{ name: '@invalid' }]
        }, {
          tags: [{ name: '@invalid' }]
        }]
      }
    }];
    _assert2.default.equal((0, _helpers.featureMatchesTags)(['@valid'], feature), false);
  });
});